@@ -5,9 +5,9 @@ from __future__ import annotations
 import abc
 from typing import Callable, ClassVar, Generic, Sequence, Tuple
 
-from stupidb.aggregator import Aggregator
-from stupidb.row import AbstractRow
-from stupidb.typehints import Getter, Output
+from .aggregator import Aggregator
+from .row import AbstractRow
+from .typehints import Getter, Output
 
 
 class Aggregate(Generic[Output], abc.ABC):
